﻿using DotNetNuke.Entities.Modules;
using DotNetNuke.Services.Exceptions;
using System;

namespace LiveChatInc {
    public partial class Settings : ModuleSettingsBase {
        public void reset_Click(Object sender, EventArgs e) {
            login.Value = string.Empty;
            license.Value = string.Empty;
            UpdateSettings();
        }

        public void apply_Click(Object sender, EventArgs e) {
            UpdateSettings();
        }

        private bool GetBoolSetting(string name, bool defaultValue) {
            bool res = defaultValue;

            Boolean.TryParse(TabModuleSettings[name] as string, out res);
            return res;
        }

        private string GetSetting(string name, string defaultValue) {
            if (TabModuleSettings[name] != null) {
                return TabModuleSettings[name] as string;
            }
            return defaultValue;
        }

        private void SetBoolSetting(ModuleController ctrl, string name, bool value) {
            ctrl.UpdateTabModuleSetting(TabModuleId, name, value.ToString());
            TabModuleSettings[name] = value.ToString();
        }

        private void SetSetting(ModuleController ctrl, string name, string value) {
            ctrl.UpdateTabModuleSetting(TabModuleId, name, value);
            TabModuleSettings[name] = value;
        }


        public override void LoadSettings() {
            try {
                if (!Page.IsPostBack) {
                    chHideOnMobile.Checked = GetBoolSetting("hideOnMobile", false);
                    license.Value = GetSetting("license", string.Empty);
                    login.Value = GetSetting("login", string.Empty);
                }
            } catch (Exception exc) {
                Exceptions.ProcessModuleLoadException(this, exc);
            }
        }

        public override void UpdateSettings() {
            try {
                ModuleController objModules = new ModuleController();
                SetBoolSetting(objModules, "hideOnMobile", chHideOnMobile.Checked);
                SetSetting(objModules, "login", login.Value);
                SetSetting(objModules, "license", license.Value);
            } catch (System.Exception exc) {
                Exceptions.ProcessModuleLoadException(this, exc);
            }
        }
    }
}